@@ -10,6 +10,7 @@ details.  */
 
 package java.lang;
 
+import java.io.File;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.IOException;
@@ -52,7 +53,10 @@ final class ConcreteProcess extends Process
     return 0;
   }
 
-  public ConcreteProcess (String[] progarray, String[] envp) throws IOException
+  public ConcreteProcess (String[] progarray,
+                          String[] envp,
+                          File dir)
+    throws IOException
   {
     throw new IOException ("eCos processes unimplemented");
   }
